<?php

namespace Drupal\custom_data\Form;

use Drupal\Core\Entity\ContentEntityForm;
use Drupal\Core\Form\FormStateInterface;
use Drupal\custom_data\CustomDataInterface;
use Drupal\entity\Form\EntityDuplicateFormTrait;

/**
 * Form controller for the custom data entity edit forms.
 */
class CustomDataForm extends ContentEntityForm {

  use EntityDuplicateFormTrait;

  /**
   * {@inheritdoc}
   */
  public function form(array $form, FormStateInterface $form_state) {
    $form = parent::form($form, $form_state);
    $form['#entity_builders']['apply_label_pattern'] = [
      static::class,
      'applyLabelPattern',
    ];
    return $form;
  }

  /**
   * {@inheritdoc}
   */
  public function save(array $form, FormStateInterface $form_state) {
    /** @var \Drupal\custom_data\CustomDataInterface $entity */
    $entity = $this->getEntity();
    $result = $entity->save();
    $link = $entity->toLink($this->t('View'))->toRenderable();

    $message_arguments = ['%label' => $this->entity->label()];
    $logger_arguments = $message_arguments + ['link' => \Drupal::service('renderer')->render($link)];

    if ($result == SAVED_NEW) {
      $this->messenger()->addStatus($this->t('New custom data %label has been created.', $message_arguments));
      $this->logger('custom_data')->notice('Created new custom data %label', $logger_arguments);
    }
    else {
      $this->messenger()->addStatus($this->t('The custom data %label has been updated.', $message_arguments));
      $this->logger('custom_data')->notice('Updated new custom data %label.', $logger_arguments);
    }

    $form_state->setRedirect('entity.custom_data.collection');
  }

  /**
   * Entity builder callback that applies the label pattern.
   *
   * @param string $entity_type_id
   *   The entity type identifier.
   * @param \Drupal\custom_data\CustomDataInterface $entity
   *   The entity updated with the submitted values.
   * @param array $form
   *   The complete form array.
   * @param \Drupal\Core\Form\FormStateInterface $form_state
   *   The current state of the form.
   */
  public static function applyLabelPattern($entity_type_id, CustomDataInterface $entity, array $form, FormStateInterface $form_state) {
    $entity->applyLabelPattern();
    // Disable the label pattern afterwards, in order to avoid redundant
    // rebuilds during the save operation chain.
    if ($entity->hasField('label_pattern')) {
      $entity->get('label_pattern')->setValue('');
    }
    else {
      $entity->label_pattern = '';
    }
  }

}
